pub struct LocalScheduleStore { /* private fields */ }Expand description
SQLite-backed schedule store for local embedded hosts.
Implementations
Sourceimpl LocalScheduleStore
impl LocalScheduleStore
Sourcepub fn new(
db: SqliteDb,
org_id: i64,
owner_principal_id: PrincipalId,
) -> Result<Self>
pub fn new( db: SqliteDb, org_id: i64, owner_principal_id: PrincipalId, ) -> Result<Self>
Open (and migrate) a schedule store over db, scoped to org_id.
Sourcepub async fn create_schedule_with_metadata(
&self,
session_id: SessionId,
description: String,
cron_expression: Option<String>,
scheduled_at: Option<DateTime<Utc>>,
timezone: String,
metadata: Value,
) -> Result<SessionSchedule>
pub async fn create_schedule_with_metadata( &self, session_id: SessionId, description: String, cron_expression: Option<String>, scheduled_at: Option<DateTime<Utc>>, timezone: String, metadata: Value, ) -> Result<SessionSchedule>
Create a schedule and persist caller-supplied extra fields in the local
metadata column. This is the additive seam that satisfies the
“extensible metadata bag” criterion without changing the core primitive.
Sourcepub async fn get_metadata(
&self,
schedule_id: ScheduleId,
) -> Result<Option<Value>>
pub async fn get_metadata( &self, schedule_id: ScheduleId, ) -> Result<Option<Value>>
Read back the metadata bag previously stored for a schedule. Returns
None when the schedule does not exist in this org scope.